<?php
/**
=============================================================================
Funcion: detectar_idioma_navegador()
-----------------------------------------------------------------------------
Proposito: Esta funcion detecta el idioma por defecto seleccionado en el navegador del visitante.
Si no se detecta un lenguaje valido, se asigna el selecionado por defecto.

=============================================================================
* @param str $defecto : el codigo del idioma por defecto
*/
function detectar_idioma_navegador($defecto=IDIOMA_DEFECTO) {
	$idiomas = array('es','en');
	$languages = preg_replace('/(;q=\d+.\d+)/i', '', getenv('HTTP_ACCEPT_LANGUAGE'));
	//es-es,es,en-us,en
	$bol_language_detected = false;	
	// Comprobamos si el navegador usa alguno de los idiomas que hemos predefinido.
	foreach ($idiomas as $tmp_arr_language) {
		if (preg_match('/' . $tmp_arr_language . '/i', $languages)) {
			$tmp_str_language_detected = $tmp_arr_language;
			$bol_language_detected = true;
			break;
		}
	}
	// Si el navegador usa uno de los idiomas seleccionados, se devuelve el path del fichero de idioma
	// En caso contrario, se devuelve el path del idioma original
	if ($bol_language_detected) {
		return $tmp_str_language_detected;
	} else {
		return $defecto;
	}
}

/**
	 * Borra los espacios,retornos de carro,tabulaciones...
	 *
	 * @param str $cadena
	 * @param str $reemplazo
	 * @return str
*/
function borraEspacios($cadena,$reemplazo="") {
	return preg_replace("/(^[\r\n]*|[\r\n]+)[\s\t]*[\r\n]+|[\n]+|[\']/",$reemplazo,$cadena);
}

/**
 * Elimina el HTML de la variable pasada y la devuelve modificada (filtrada)
 *
 * @param str $variable
 * @return str
 */
function borraHTML($variable){
	$variable = preg_replace('/<(.|\s)*?>/', '', $variable);
	$variable = str_replace('<','',$variable);
	$variable = str_replace('>',"",$variable);
	return $variable;
}
/**
 * Pasar de &aacute; a 
 * @param str $str
 * @return str
 */
function parsearAcentosHTML($str){
	$acentos = array("&aacute;","&eacute;","&iacute;","&oacute;","&uacute;");
	$acentos2= array("&Aacute;","&Eacute;","&Iacute;","&Oacute;","&Uacute;");
	$especiales=array("&ntilde;","&Ntilde;","&nbsp;","&ordm;","&ordf;");
	$acentosUTF8 = array('','','','','');
	$acentosUTF8_2 = array('','','','','');
	$especiales2 = array('','','<br>','','');
	for($i=0; $i<sizeof($acentos); $i++){
		$str = str_replace($acentos[$i],$acentosUTF8[$i],$str);
		$str = str_replace($acentos2[$i],$acentosUTF8_2[$i],$str);
		$str = str_replace($especiales[$i],$especiales2[$i],$str);
	}
	return $str;
}

/**
 * Le pasa html entities y addslashes para guardar html y caracteres extraos en la bd
 * @param str :html $var
 *
 * @return str
 */
function parsear_html($var){
	//return htmlentities(addslashes($var));
	return addslashes(str_replace('"',"'",$var));
}
/**
 * Devuelve el texto a su estado original de la bd a html
 *
 * @param str $var
 * @return str : html
 */
function reconstruye_html($var){
	//return stripslashes(html_entity_decode($var));
	return stripslashes($var);
}


/**
 * Obtiene el valor adecuado de la variable desde GET o POST. Si cookies = true tambi�n comprueba de la cookie...
 *
 * @param str $nombre
 * @param bool $cookies
 * @param int $defecto : valor por defecto
 * @return int valor de la variable en entero
 */
function parsearEntero($nombre,$defecto=1,$cookies=false) {
	if (isset( $_GET[$nombre]) ) {
	 $valor = intval($_GET[$nombre]);
	} elseif (isset( $_POST[$nombre] ) ) {
		 $valor = intval($_POST[$nombre]);
	} elseif ($cookies && isset($_COOKIE[$nombre])) {
	  $valor = intval($_COOKIE[$nombre]);
		} else {
	  $valor = $defecto;
	}
	return $valor;
}

/**
 * Formato para DS -> dia/mes/ao
 * Formato para los dems ...
 *
 * @param str $quecosa
 * @param date $_fecha
 * @param str $idioma : codigo del idioma ,el directorio dentro de DIR_IDIOMAS
 * @return str||date
 */
function parsearFechaTexto($quecosa='t',$_fecha="",$idioma=IDIOMA_DEFECTO) { //t = toda la fecha
	require_once(DIR_IDIOMAS.$idioma.'/fecha.php');
	$diassemana = array(TEXT_DOMINGO,TEXT_LUNES,TEXT_MARTES,TEXT_MIERCOLES,TEXT_JUEVES,TEXT_VIERNES,TEXT_SABADO) ;
	$mesesano = array(TEXT_ENERO,TEXT_FEBRERO,TEXT_MARZO,TEXT_ABRIL,TEXT_MAYO,
		TEXT_JUNIO,TEXT_JULIO,TEXT_AGOSTO,TEXT_SEPTIEMBRE,TEXT_OCTUBRE,
		TEXT_NOVIEMBRE,TEXT_DICIEMBRE);
	switch ($quecosa) {
	case 'd':
		return $diassemana[date('w')];
		break;
	case 'dm':
		return date('j') ;
		break;
	case 'm':
		return $mesesano[date('n')] - 1 ;
		break;
	case 'y':
		return date('Y') ;
		break;
	case 'DS': //Dia de la semana de una fecha en concreto
		$fecha = split('/',$_fecha);
		return  $diassemana[date('w',mktime(0,0,0,$fecha[1],$fecha[0],$fecha[2]))]." ".$fecha[0]." ".TEXT_DE." ".
				$mesesano[intval($fecha[1])]." ".TEXT_DEL." ".$fecha[2];
		break;
	default: //toda la fecha completa
		return $diassemana[$diassemana[date('w')]].",".date('j')."/".($mesesano[date('n')] - 1)."/".date('Y');
		break;
	}
}

/**
 * Convierte fecha de mysql a normal
 *
 * @param date(Y-m-d) $fecha
 * @return date(d/m/Y)
 */
function parsear_fecha_a_normal($fecha){
	ereg( "([0-9]{2,4})-([0-9]{1,2})-([0-9]{1,2})", $fecha, $mifecha);
	$lafecha=$mifecha[3]."/".$mifecha[2]."/".$mifecha[1];
	return $lafecha;
}

/**
 * Convierte fecha de normal a mysql
 *
 * @param date(d/m/Y) $fecha
 * @return date(Y-m-d)
 */
function parsear_fecha_a_mysql($fecha){
	ereg( "([0-9]{1,2})/([0-9]{1,2})/([0-9]{2,4})", $fecha, $mifecha);
	$lafecha=$mifecha[3]."-".$mifecha[2]."-".$mifecha[1];
	return $lafecha;
}

/**
 * Filtra un texto como fecha del formato [0-9]{1,2})/([0-9]{1,2})/([0-9]{2,4}
 *
 * @param str $fecha
 * @return str : ([0-9]{1,2})/([0-9]{1,2})/([0-9]{2,4})
 */
function parsearFechaFormato($fecha){
	ereg( "([0-9]{1,2})/([0-9]{1,2})/([0-9]{2,4})", $fecha, $mifecha);
	$lafecha=$mifecha[1]."/".$mifecha[2]."/".$mifecha[3];
	return $lafecha;
}
/**
 * Sanea y devuelve todo el GET evitando las llaves pasadas en una lista como cadena entre comas ("len,idp,...")
 *
 * @param str $evitar
 * @return str
 */
function parsear_get_enviado($evitar=""){
	if (!isset($_GET)) return "";
	$evitar = split(",",$evitar);
	$cadena ="?";
	foreach ($_GET as $llave => $valor) {
		if (!in_array($llave,$evitar)){
		 if ($cadena!="?") $cadena .="&";
		 $cadena .= sanar($llave)."=".sanar($valor);
		}
	}
	return $cadena;
}

/**
 * Limpia todo el html y las comillas de una cadena devolviendola filtrada
 *
 * @param str $variable
 * @return str
 */
function sanar($variable){	
	return addslashes(borraHTML($variable));
}
/**
 * Serializa un array usando comas para la cadena resultante
 *
 * @param str $array
 * @return str
 */
function serializar(&$array){
	$str ="";
	$n = count($array);
	for ($i=0; $i<$n; $i++){
		$str .= $array[$i];
		if ($i<$n) $str .= ",";
	}
	return $str;
}
/**
 * Deserializa una cadena en un array usando como patrn la coma
 *
 * @param str $cadena
 * @return array
 */
function deserializar($cadena){
	return split(",",$cadena);
}

?>